#| -*-Scheme-*- |#

(define-load-option 'blowfish
  (standard-system-loader "."))

(further-load-options #t)